@@ -25,6 +25,7 @@ class Connection(object):
             if chn not in self.channels:
                 self.channels.append(chn)
 
+
     def regist_trigger(self, on_data):
         self.when_data = on_data
 
@@ -90,17 +91,46 @@ def parse_command(*argv):
 
 
 
+class Blocker(object):
+    def __init__(self, host, port, db):
+        self.conn = None
+        self.conn_params = (host, port, db)
+        self.callbacks = {}
+        self.state_ok = False
+        self.reconnect(*self.conn_params)
+
+
+    def reconnect(self, host, port, db):
+        def on_line(type, data):
+            self.on_data(type, data)
+        self.conn = Connection(host, port)
+        self.conn.regist_trigger(on_line)
+        self.conn.write(parse_command("SELECT", str(db)))
+        self.state_ok = True
+        self.conn.recive()
+
+    def on_data(self, chunk_type, data):
+        if chunk_type == MULTI_BULK_REPLY and data[0] in self.callbacks :
+            callback = self.callbacks[data[0]]
+            callback(data[1])
+            del self.callbacks[data[0]]
+
+    def blpop(self, key, callback, timeout=300):
+        self.callbacks[key] = callback
+        self.conn.write(parse_command("blpop", key, timeout))
+
+
 class Subscriber(object):
     def __init__(self, host, port, db):
         self.conn = None
         self.send_conn = None
         self.conn_params = (host,port,db)
-        self.reconnect(*self.conn_params)
         self.data_pool = []
         self.param_len = -1
         self.callback = None
         self.channels = None
         self.state_ok = False
+        self.reconnect(*self.conn_params)
 
     def listen_on(self, channels, callback):
         self.conn.write(parse_command("subscribe", *channels))
@@ -127,6 +157,7 @@ class Subscriber(object):
         if chunk_type == MULTI_BULK_REPLY and data[0] == "message":
             self.callback(data[1], data[2])
 
+
     def check_connection(self):
         if not self.state_ok:
             self.reconnect(*self.conn_params)
